@@ -44,7 +44,7 @@ mailing_list       = 'python-debugger@googlegroups.com'
 modname            = 'xdis'
 py_modules         = None
 # setup_requires     = ['pytest-runner']
-scripts            = ['bin/pydisasm']
+scripts            = ['bin/pydisasm.py']
 short_desc         = 'Python cross-version byte-code disassembler and marshal routines'
 tests_require      = ['pytest', _six]
 web                = 'https://github.com/rocky/python-xdis/'
